==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/AssigningShapeMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescription } from "./AssigningShapeMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningShapeMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningShapeMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningShapeMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningShapeMarkerStyleEventArgsDescriptionMetadata.c(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningShapeMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningShapeMarkerStyleEventArgs", function () { return new AssigningShapeMarkerStyleEventArgsDescription(); });
        a.z("AssigningShapeMarkerStyleEventArgs", AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningShapeMarkerStyleEventArgsDescriptionMetadata, 'AssigningShapeMarkerStyleEventArgsDescriptionMetadata');
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningShapeMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningShapeMarkerStyleEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/AssigningShapeMarkerStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningShapeMarkerStyleEventArgsDescription } from "./AssigningShapeMarkerStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningShapeMarkerStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningShapeMarkerStyleEventArgsDescriptionMetadata, _super);
    function AssigningShapeMarkerStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a == null) {
            AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningShapeMarkerStyleEventArgsDescriptionMetadata.c(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
        }
        if (a.k(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningShapeMarkerStyleEventArgsDescriptionMetadata.b(a);
        a.ac("AssigningShapeMarkerStyleEventArgs", function () { return new AssigningShapeMarkerStyleEventArgsDescription(); });
        a.ab("AssigningShapeMarkerStyleEventArgs", AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a);
    };
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.$t = markType(AssigningShapeMarkerStyleEventArgsDescriptionMetadata, 'AssigningShapeMarkerStyleEventArgsDescriptionMetadata');
    AssigningShapeMarkerStyleEventArgsDescriptionMetadata.a = null;
    return AssigningShapeMarkerStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningShapeMarkerStyleEventArgsDescriptionMetadata };
